@@ -184,7 +184,7 @@ impl<I, P> PriorityQueue<I, P>
                 let tmp = *self.heap.get_unchecked(pos);
                 while (pos > 0) &&
                     (self.map.get_index(*self.heap.get_unchecked(parent(pos))).unwrap().1 <
-                     self.map.get_index(*self.heap.get_unchecked(pos)).unwrap().1)
+                     self.map.get_index(tmp).unwrap().1)
                 {
                     *self.heap.get_unchecked_mut(pos) = *self.heap.get_unchecked(parent(pos));
                     *self.qp.get_unchecked_mut(*self.heap.get_unchecked(pos)) = pos;
@@ -443,15 +443,14 @@ impl<I, P> PriorityQueue<I, P>
     fn heapify(&mut self, i: usize) {
         let (mut l, mut r) = (left(i), right(i));
         let mut i = i;
-        let mut largest; 
-        if l < self.size &&
+        let mut largest = if l < self.size &&
             unsafe {self.map.get_index(*self.heap.get_unchecked(l)).unwrap().1 >
                     self.map.get_index(*self.heap.get_unchecked(i)).unwrap().1}
         {
-            largest = l;
+            l
         } else {
-            largest = i;
-        }
+            i
+        };
         if r < self.size &&
             unsafe {self.map.get_index(*self.heap.get_unchecked(r)).unwrap().1 >
                     self.map.get_index(*self.heap.get_unchecked(largest)).unwrap().1}
